@@ -1,5 +1,5 @@
 /*
-    htpdate v1.3.5
+    htpdate v1.3.6
 
     Eddy Vervest <eddy@vervest.org>
     http://www.vervest.org/htp
@@ -61,7 +61,7 @@
 #include <openssl/ssl.h>
 #endif
 
-#define VERSION                  "1.3.5"
+#define VERSION                  "1.3.6"
 #define MAX_HTTP_HOSTS           16                /* 16 web servers */
 #define DEFAULT_HTTP_PORT        "80"
 #define DEFAULT_PROXY_PORT       "8080"
@@ -809,8 +809,8 @@ int main(int argc, char *argv[]) {
             exit(0);
         case 'x':               /* adjust time and clock frequency */
             setmode = 3;
-	    if (maxsleep > 14400) maxsleep = 14400;
-	    if (precision < 7) precision = 7;
+            if (maxsleep > 14400) maxsleep = 14400;
+            if (precision < 7) precision = 7;
             break;
         case 'D':               /* run as daemon */
             daemonize = 1;
@@ -936,7 +936,7 @@ int main(int argc, char *argv[]) {
         /* Check if we have at least one valid response */
         if (goodtimes) {
 
-            timeavg = sumtimes / goodtimes / 2;
+            timeavg = sumtimes / goodtimes;
 
             if (debug > 1)
                 printlog(0, "#: %d, mean: %.3f, average: %.3f", goodtimes, mean, timeavg);
@@ -978,7 +978,7 @@ int main(int argc, char *argv[]) {
             } else {
                 /* Increase polling interval */
                 if (sleeptime < maxsleep) sleeptime <<= 1;
-		if (setmode == 3) setstatus(precision);
+                if (setmode == 3) setstatus(precision);
             }
 
             if (daemonize || foreground) {
@@ -986,6 +986,9 @@ int main(int argc, char *argv[]) {
                 sleep(sleeptime);
             }
 
+            /* After first successful poll cycle do not step through time, only adjust */
+            if (setmode != 3) setmode = 1;
+
         } else {
             printlog(1, "No server suitable for synchronization found");
             /* Sleep for minsleep to avoid flooding */
@@ -995,9 +998,6 @@ int main(int argc, char *argv[]) {
                 exit(1);
         }
 
-        /* After first poll cycle do not step through time, only adjust */
-        if (setmode != 3) setmode = 1;
-
     } while (daemonize || foreground);         /* end of infinite while loop */
 
     exit(0);
